import { ElementRef, AfterContentInit, AfterViewInit, AfterViewChecked, OnInit, OnDestroy, ViewContainerRef, IterableDiffers, EventEmitter, Renderer2, QueryList, TemplateRef, ChangeDetectorRef, EmbeddedViewRef, NgZone } from '@angular/core';
import { Column, HeaderColumnGroup, FooterColumnGroup, PrimeTemplate } from '../common/shared';
import { LazyLoadEvent } from '../common/lazyloadevent';
import { FilterMetadata } from '../common/filtermetadata';
import { SortMeta } from '../common/sortmeta';
import { DomHandler } from '../dom/domhandler';
import { ObjectUtils } from '../utils/objectutils';
import { Subscription } from 'rxjs/internal/Subscription';
import { BlockableUI } from '../common/blockableui';
import * as i0 from "@angular/core";
import * as i1 from "@angular/common";
import * as i2 from "../common/shared";
import * as i3 from "../paginator/paginator";
import * as i4 from "@angular/forms";
export declare class DataTable implements AfterViewChecked, AfterViewInit, AfterContentInit, OnInit, OnDestroy, BlockableUI {
    el: ElementRef;
    domHandler: DomHandler;
    differs: IterableDiffers;
    renderer: Renderer2;
    changeDetector: ChangeDetectorRef;
    objectUtils: ObjectUtils;
    zone: NgZone;
    paginator: boolean;
    rows: number;
    pageLinks: number;
    rowsPerPageOptions: number[];
    responsive: boolean;
    stacked: boolean;
    selectionMode: string;
    selectionChange: EventEmitter<any>;
    editable: boolean;
    showHeaderCheckbox: boolean;
    onRowClick: EventEmitter<any>;
    onRowSelect: EventEmitter<any>;
    onRowUnselect: EventEmitter<any>;
    onRowDblclick: EventEmitter<any>;
    onHeaderCheckboxToggle: EventEmitter<any>;
    headerCheckboxToggleAllPages: boolean;
    onContextMenuSelect: EventEmitter<any>;
    filterDelay: number;
    lazy: boolean;
    onLazyLoad: EventEmitter<any>;
    resizableColumns: boolean;
    columnResizeMode: string;
    onColResize: EventEmitter<any>;
    reorderableColumns: boolean;
    onColReorder: EventEmitter<any>;
    scrollable: boolean;
    virtualScroll: boolean;
    scrollHeight: any;
    scrollWidth: any;
    frozenWidth: any;
    unfrozenWidth: any;
    style: any;
    styleClass: string;
    tableStyle: any;
    tableStyleClass: string;
    globalFilter: any;
    sortMode: string;
    defaultSortOrder: number;
    groupField: string;
    contextMenu: any;
    csvSeparator: string;
    exportFilename: string;
    emptyMessage: string;
    paginatorPosition: string;
    alwaysShowPaginator: boolean;
    metaKeySelection: boolean;
    rowTrackBy: Function;
    immutable: boolean;
    frozenValue: any[];
    compareSelectionBy: string;
    onEditInit: EventEmitter<any>;
    onEditComplete: EventEmitter<any>;
    onEdit: EventEmitter<any>;
    onEditCancel: EventEmitter<any>;
    onPage: EventEmitter<any>;
    onSort: EventEmitter<any>;
    onFilter: EventEmitter<any>;
    header: any;
    footer: any;
    expandableRows: boolean;
    expandedRows: any[];
    expandableRowGroups: boolean;
    rowExpandMode: string;
    expandedRowsGroups: any[];
    expandedIcon: string;
    collapsedIcon: string;
    tabindex: number;
    rowStyleClass: Function;
    rowStyleMap: Object;
    rowGroupMode: string;
    sortableRowGroup: boolean;
    sortFile: string;
    rowHover: boolean;
    filters: {
        [s: string]: FilterMetadata;
    };
    dataKey: string;
    loading: boolean;
    loadingIcon: string;
    virtualScrollDelay: number;
    rowGroupExpandMode: string;
    valueChange: EventEmitter<any[]>;
    firstChange: EventEmitter<number>;
    onRowExpand: EventEmitter<any>;
    onRowCollapse: EventEmitter<any>;
    onRowGroupExpand: EventEmitter<any>;
    onRowGroupCollapse: EventEmitter<any>;
    templates: QueryList<PrimeTemplate>;
    cols: QueryList<Column>;
    headerColumnGroups: QueryList<HeaderColumnGroup>;
    footerColumnGroups: QueryList<FooterColumnGroup>;
    _value: any[];
    dataToRender: any[];
    page: number;
    filterTimeout: any;
    filteredValue: any[];
    columns: Column[];
    frozenColumns: Column[];
    scrollableColumns: Column[];
    frozenHeaderColumnGroup: HeaderColumnGroup;
    scrollableHeaderColumnGroup: HeaderColumnGroup;
    frozenFooterColumnGroup: HeaderColumnGroup;
    scrollableFooterColumnGroup: HeaderColumnGroup;
    columnsChanged: boolean;
    sortColumn: Column;
    columnResizing: boolean;
    lastResizerHelperX: number;
    documentEditListener: Function;
    documentColumnResizeEndListener: Function;
    resizerHelper: any;
    resizeColumn: any;
    reorderIndicatorUp: any;
    reorderIndicatorDown: any;
    iconWidth: number;
    iconHeight: number;
    draggedColumn: any;
    dropPosition: number;
    tbody: any;
    rowTouched: boolean;
    rowGroupToggleClick: boolean;
    editingCell: any;
    virtualTableHeight: number;
    rowGroupMetadata: any;
    rowGroupHeaderTemplate: TemplateRef<any>;
    rowGroupFooterTemplate: TemplateRef<any>;
    rowExpansionTemplate: TemplateRef<any>;
    emptyMessageTemplate: TemplateRef<any>;
    scrollBarWidth: number;
    editorClick: boolean;
    _first: number;
    selectionKeys: any;
    preventSelectionKeysPropagation: boolean;
    preventSortPropagation: boolean;
    preventRowClickPropagation: boolean;
    _multiSortMeta: SortMeta[];
    _sortField: string;
    _sortOrder: number;
    differ: any;
    _selection: any;
    _totalRecords: number;
    globalFilterFunction: any;
    columnsSubscription: Subscription;
    totalRecordsChanged: boolean;
    anchorRowIndex: number;
    rangeRowIndex: number;
    initialized: boolean;
    virtualScrollTimer: any;
    virtualScrollableTableWrapper: HTMLDivElement;
    virtualScrollCallback: Function;
    editChanged: boolean;
    resizeTimeout: any;
    resizeAutoFitTimeout: any;
    constructor(el: ElementRef, domHandler: DomHandler, differs: IterableDiffers, renderer: Renderer2, changeDetector: ChangeDetectorRef, objectUtils: ObjectUtils, zone: NgZone);
    ngOnInit(): void;
    ngAfterContentInit(): void;
    measureText(pText: any, pFontSize: any): number;
    onWindowResize(event: any): void;
    autoFitHeightWidth(): void;
    ngAfterViewChecked(): void;
    ngAfterViewInit(): void;
    get multiSortMeta(): SortMeta[];
    set multiSortMeta(val: SortMeta[]);
    get sortField(): string;
    set sortField(val: string);
    get sortOrder(): number;
    set sortOrder(val: number);
    get value(): any[];
    set value(val: any[]);
    get first(): number;
    set first(val: number);
    get totalRecords(): number;
    set totalRecords(val: number);
    get selection(): any;
    set selection(val: any);
    ngDoCheck(): void;
    handleDataChange(): void;
    initColumns(): void;
    initScrollableColumns(): void;
    initColumnGroups(): void;
    resolveFieldData(data: any, field: string): any;
    updateRowGroupMetadata(): void;
    updatePaginator(): void;
    updateTotalRecords(): void;
    onPageChange(event: any): void;
    paginate(): void;
    updateDataToRender(datasource: any): void;
    onVirtualScroll(event: any): void;
    onHeaderKeydown(event: any, column: Column): void;
    onHeaderMousedown(event: any, header: any): void;
    sort(event: any, column: Column): void;
    sortSingle(): void;
    sortMultiple(): void;
    multisortField(data1: any, data2: any, multiSortMeta: any, index: any): any;
    addSortMeta(meta: any): void;
    isSorted(column: Column): boolean;
    getSortOrder(column: Column): number;
    onRowGroupClick(event: any): void;
    clearSelectionRange(): void;
    selectRange(rowIndex: number): void;
    handleRowClick(event: MouseEvent, rowData: any, index: number): void;
    handleRowTouchEnd(event: Event): void;
    selectRowWithRadio(event: Event, rowData: any): void;
    toggleRowWithCheckbox(event: any, rowData: any): void;
    toggleRowsWithCheckbox(event: any): void;
    onRowRightClick(event: any, rowData: any): void;
    rowDblclick(event: any, rowData: any): void;
    isSingleSelectionMode(): boolean;
    isMultipleSelectionMode(): boolean;
    findIndexInSelection(rowData: any): number;
    isSelected(rowData: any): boolean;
    equals(data1: any, data2: any): boolean;
    get allSelected(): boolean;
    onFilterKeyup(value: any, field: any, matchMode: any): void;
    filter(value: any, field: any, matchMode: any): void;
    isFilterBlank(filter: any): boolean;
    _filter(): void;
    hasFilter(): any;
    onFilterInputClick(event: any): void;
    filterConstraints: {
        startsWith(value: any, filter: any): boolean;
        contains(value: any, filter: any): boolean;
        endsWith(value: any, filter: any): boolean;
        equals(value: any, filter: any): boolean;
        notEquals(value: any, filter: any): boolean;
        in(value: any, filter: any[]): boolean;
    };
    switchCellToEditMode(cell: any, column: Column, rowData: any): void;
    switchCellToViewMode(element: any): void;
    closeCell(): void;
    bindDocumentEditListener(): void;
    unbindDocumentEditListener(): void;
    onCellEditorKeydown(event: any, column: Column, rowData: any, rowIndex: number): void;
    onCellEditorInput(event: any, column: Column, rowData: any, rowIndex: number): void;
    onCellEditorChange(event: any, column: Column, rowData: any, rowIndex: number): void;
    onCellEditorBlur(event: any, column: Column, rowData: any, rowIndex: number): void;
    moveToPreviousCell(event: KeyboardEvent): void;
    moveToNextCell(event: KeyboardEvent): void;
    findPreviousEditableColumn(cell: Element): any;
    findNextEditableColumn(cell: Element): any;
    onCustomEditorFocusPrev(event: KeyboardEvent): void;
    onCustomEditorFocusNext(event: KeyboardEvent): void;
    findCell(element: any): any;
    initResizableColumns(): void;
    onDocumentMouseMove(event: any): void;
    onDocumentMouseUp(event: any): void;
    bindColumnResizeEvents(): void;
    unbindColumnResizeEvents(): void;
    initColumnResize(event: any): void;
    onColumnResize(event: any): void;
    onColumnResizeEnd(event: any): void;
    fixColumnWidths(): void;
    onColumnDragStart(event: any): void;
    onColumnDragover(event: any): void;
    onColumnDragleave(event: any): void;
    onColumnDrop(event: any): void;
    initColumnReordering(): void;
    findParentHeader(element: any): any;
    hasFooter(): boolean;
    isEmpty(): boolean;
    createLazyLoadMetadata(): LazyLoadEvent;
    toggleRow(row: any, event?: Event): void;
    findExpandedRowIndex(row: any): number;
    isRowExpanded(row: any): boolean;
    findExpandedRowGroupIndex(row: any): number;
    isRowGroupExpanded(row: any): boolean;
    toggleRowGroup(event: Event, row: any): void;
    reset(): void;
    exportCSV(options?: any): void;
    getBlockableElement(): HTMLElement;
    getRowStyleClass(rowData: any, rowIndex: number): string;
    visibleColumns(): Column[];
    get containerWidth(): any;
    hasFrozenColumns(): boolean;
    ngOnDestroy(): void;
    static ɵfac: i0.ɵɵFactoryDef<DataTable, never>;
    static ɵcmp: i0.ɵɵComponentDefWithMeta<DataTable, "p-dataTable", never, { "paginator": "paginator"; "rows": "rows"; "pageLinks": "pageLinks"; "rowsPerPageOptions": "rowsPerPageOptions"; "responsive": "responsive"; "stacked": "stacked"; "selectionMode": "selectionMode"; "editable": "editable"; "showHeaderCheckbox": "showHeaderCheckbox"; "headerCheckboxToggleAllPages": "headerCheckboxToggleAllPages"; "filterDelay": "filterDelay"; "lazy": "lazy"; "resizableColumns": "resizableColumns"; "columnResizeMode": "columnResizeMode"; "reorderableColumns": "reorderableColumns"; "scrollable": "scrollable"; "virtualScroll": "virtualScroll"; "scrollHeight": "scrollHeight"; "scrollWidth": "scrollWidth"; "frozenWidth": "frozenWidth"; "unfrozenWidth": "unfrozenWidth"; "style": "style"; "styleClass": "styleClass"; "tableStyle": "tableStyle"; "tableStyleClass": "tableStyleClass"; "globalFilter": "globalFilter"; "sortMode": "sortMode"; "defaultSortOrder": "defaultSortOrder"; "groupField": "groupField"; "contextMenu": "contextMenu"; "csvSeparator": "csvSeparator"; "exportFilename": "exportFilename"; "emptyMessage": "emptyMessage"; "paginatorPosition": "paginatorPosition"; "alwaysShowPaginator": "alwaysShowPaginator"; "metaKeySelection": "metaKeySelection"; "rowTrackBy": "rowTrackBy"; "immutable": "immutable"; "frozenValue": "frozenValue"; "compareSelectionBy": "compareSelectionBy"; "expandableRows": "expandableRows"; "expandedRows": "expandedRows"; "expandableRowGroups": "expandableRowGroups"; "rowExpandMode": "rowExpandMode"; "expandedRowsGroups": "expandedRowsGroups"; "expandedIcon": "expandedIcon"; "collapsedIcon": "collapsedIcon"; "tabindex": "tabindex"; "rowStyleClass": "rowStyleClass"; "rowStyleMap": "rowStyleMap"; "rowGroupMode": "rowGroupMode"; "sortableRowGroup": "sortableRowGroup"; "sortFile": "sortFile"; "rowHover": "rowHover"; "filters": "filters"; "dataKey": "dataKey"; "loading": "loading"; "loadingIcon": "loadingIcon"; "virtualScrollDelay": "virtualScrollDelay"; "rowGroupExpandMode": "rowGroupExpandMode"; "multiSortMeta": "multiSortMeta"; "sortField": "sortField"; "sortOrder": "sortOrder"; "value": "value"; "first": "first"; "totalRecords": "totalRecords"; "selection": "selection"; }, { "selectionChange": "selectionChange"; "onRowClick": "onRowClick"; "onRowSelect": "onRowSelect"; "onRowUnselect": "onRowUnselect"; "onRowDblclick": "onRowDblclick"; "onHeaderCheckboxToggle": "onHeaderCheckboxToggle"; "onContextMenuSelect": "onContextMenuSelect"; "onLazyLoad": "onLazyLoad"; "onColResize": "onColResize"; "onColReorder": "onColReorder"; "onEditInit": "onEditInit"; "onEditComplete": "onEditComplete"; "onEdit": "onEdit"; "onEditCancel": "onEditCancel"; "onPage": "onPage"; "onSort": "onSort"; "onFilter": "onFilter"; "valueChange": "valueChange"; "firstChange": "firstChange"; "onRowExpand": "onRowExpand"; "onRowCollapse": "onRowCollapse"; "onRowGroupExpand": "onRowGroupExpand"; "onRowGroupCollapse": "onRowGroupCollapse"; }, ["header", "footer", "templates", "cols", "headerColumnGroups", "footerColumnGroups"], ["p-header", "p-footer"]>;
}
export declare class DTRadioButton {
    checked: boolean;
    onClick: EventEmitter<any>;
    hover: boolean;
    handleClick(event: any): void;
    static ɵfac: i0.ɵɵFactoryDef<DTRadioButton, never>;
    static ɵcmp: i0.ɵɵComponentDefWithMeta<DTRadioButton, "p-dtRadioButton", never, { "checked": "checked"; }, { "onClick": "onClick"; }, never, never>;
}
export declare class DTCheckbox {
    checked: boolean;
    disabled: boolean;
    onChange: EventEmitter<any>;
    hover: boolean;
    handleClick(event: any): void;
    static ɵfac: i0.ɵɵFactoryDef<DTCheckbox, never>;
    static ɵcmp: i0.ɵɵComponentDefWithMeta<DTCheckbox, "p-dtCheckbox", never, { "checked": "checked"; "disabled": "disabled"; }, { "onChange": "onChange"; }, never, never>;
}
export declare class RowExpansionLoader implements OnInit, OnDestroy {
    viewContainer: ViewContainerRef;
    template: TemplateRef<any>;
    rowData: any;
    rowIndex: any;
    view: EmbeddedViewRef<any>;
    constructor(viewContainer: ViewContainerRef);
    ngOnInit(): void;
    ngOnDestroy(): void;
    static ɵfac: i0.ɵɵFactoryDef<RowExpansionLoader, never>;
    static ɵcmp: i0.ɵɵComponentDefWithMeta<RowExpansionLoader, "p-rowExpansionLoader", never, { "template": "template"; "rowData": "rowData"; "rowIndex": "rowIndex"; }, {}, never, never>;
}
export declare class ColumnHeaders {
    dt: DataTable;
    constructor(dt: DataTable);
    columns: Column[];
    static ɵfac: i0.ɵɵFactoryDef<ColumnHeaders, never>;
    static ɵcmp: i0.ɵɵComponentDefWithMeta<ColumnHeaders, "[pColumnHeaders]", never, { "columns": "pColumnHeaders"; }, {}, never, never>;
}
export declare class ColumnFooters {
    dt: DataTable;
    constructor(dt: DataTable);
    columns: Column[];
    static ɵfac: i0.ɵɵFactoryDef<ColumnFooters, never>;
    static ɵcmp: i0.ɵɵComponentDefWithMeta<ColumnFooters, "[pColumnFooters]", never, { "columns": "pColumnFooters"; }, {}, never, never>;
}
export declare class TableBody {
    dt: DataTable;
    constructor(dt: DataTable);
    columns: Column[];
    data: any[];
    visibleColumns(): Column[];
    static ɵfac: i0.ɵɵFactoryDef<TableBody, never>;
    static ɵcmp: i0.ɵɵComponentDefWithMeta<TableBody, "[pTableBody]", never, { "columns": "pTableBody"; "data": "data"; }, {}, never, never>;
}
export declare class ScrollableView implements AfterViewInit, AfterViewChecked, OnDestroy {
    dt: DataTable;
    domHandler: DomHandler;
    el: ElementRef;
    renderer: Renderer2;
    zone: NgZone;
    constructor(dt: DataTable, domHandler: DomHandler, el: ElementRef, renderer: Renderer2, zone: NgZone);
    columns: Column[];
    headerColumnGroup: HeaderColumnGroup;
    footerColumnGroup: HeaderColumnGroup;
    scrollHeaderViewChild: ElementRef;
    scrollHeaderBoxViewChild: ElementRef;
    scrollBodyViewChild: ElementRef;
    scrollTableViewChild: ElementRef;
    scrollTableWrapperViewChild: ElementRef;
    scrollFooterViewChild: ElementRef;
    scrollFooterBoxViewChild: ElementRef;
    frozen: boolean;
    width: string;
    virtualScroll: boolean;
    onVirtualScroll: EventEmitter<any>;
    scrollBody: HTMLDivElement;
    scrollHeader: HTMLDivElement;
    scrollHeaderBox: HTMLDivElement;
    scrollTable: HTMLDivElement;
    scrollTableWrapper: HTMLDivElement;
    scrollFooter: HTMLDivElement;
    scrollFooterBox: HTMLDivElement;
    bodyScrollListener: Function;
    headerScrollListener: Function;
    scrollBodyMouseWheelListener: Function;
    scrollFunction: Function;
    rowHeight: number;
    scrollTimeout: any;
    ngAfterViewInit(): void;
    ngAfterViewChecked(): void;
    initScrolling(): void;
    onBodyScroll(event: any): void;
    setScrollHeight(): void;
    onHeaderScroll(event: any): void;
    hasVerticalOverflow(): boolean;
    alignScrollBar(): void;
    ngOnDestroy(): void;
    static ɵfac: i0.ɵɵFactoryDef<ScrollableView, never>;
    static ɵcmp: i0.ɵɵComponentDefWithMeta<ScrollableView, "[pScrollableView]", never, { "columns": "pScrollableView"; "headerColumnGroup": "headerColumnGroup"; "footerColumnGroup": "footerColumnGroup"; "frozen": "frozen"; "width": "width"; "virtualScroll": "virtualScroll"; }, { "onVirtualScroll": "onVirtualScroll"; }, never, never>;
}
export declare class DataTableModule {
    static ɵmod: i0.ɵɵNgModuleDefWithMeta<DataTableModule, [typeof DataTable, typeof DTRadioButton, typeof DTCheckbox, typeof ColumnHeaders, typeof ColumnFooters, typeof TableBody, typeof ScrollableView, typeof RowExpansionLoader], [typeof i1.CommonModule, typeof i2.SharedModule, typeof i3.PaginatorModule, typeof i4.FormsModule], [typeof DataTable, typeof i2.SharedModule]>;
    static ɵinj: i0.ɵɵInjectorDef<DataTableModule>;
}
